==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QWheelEvent_shell.h <==
#ifndef QWHEELEVENT_SHELL_H
#define QWHEELEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtGui/qeventpoint.h>
#include <QtGui/qinputdevice.h>
#include <QtGui/qpointingdevice.h>
#include <QtJambi/RegistryAPI>


class QWheelEvent_shell : public QWheelEvent, public QtJambiShellInterface
{
public:
    QWheelEvent_shell(const QPointF& pos0, const QPointF& globalPos1, QPoint pixelDelta2, QPoint angleDelta3, Qt::MouseButtons buttons4, Qt::KeyboardModifiers modifiers5, Qt::ScrollPhase phase6, bool inverted7, Qt::MouseEventSource source8 = Qt::MouseEventNotSynthesized, const QPointingDevice* device9 = QPointingDevice::primaryPointingDevice());
    QWheelEvent_shell(const QWheelEvent& arg__1);
    ~QWheelEvent_shell() override;

    QWheelEvent* clone() const override;
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted0) override;
    void setTimestamp(quint64 timestamp0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QWheelEvent_access : public QWheelEvent
{
    void __qt_assign_cref_QWheelEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isBeginEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isEndEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isUpdateEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QWHEELEVENT_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QWheelEvent_shell.h <==
#ifndef QWHEELEVENT_SHELL_H
#define QWHEELEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtGui/qeventpoint.h>
#include <QtGui/qinputdevice.h>
#include <QtGui/qpointingdevice.h>
#include <QtJambi/RegistryAPI>


class QWheelEvent_shell : public QWheelEvent, public QtJambiShellInterface
{
public:
    QWheelEvent_shell(const QPointF& pos0, const QPointF& globalPos1, QPoint pixelDelta2, QPoint angleDelta3, Qt::MouseButtons buttons4, Qt::KeyboardModifiers modifiers5, Qt::ScrollPhase phase6, bool inverted7, Qt::MouseEventSource source8 = Qt::MouseEventNotSynthesized, const QPointingDevice* device9 = QPointingDevice::primaryPointingDevice());
    QWheelEvent_shell(const QWheelEvent& arg__1);
    ~QWheelEvent_shell() override;

    QWheelEvent* clone() const override;
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted0) override;
    void setTimestamp(quint64 timestamp0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QWheelEvent_access : public QWheelEvent
{
    void __qt_assign_cref_QWheelEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isBeginEvent_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isEndEvent_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isUpdateEvent_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QWHEELEVENT_SHELL_H
